package com.zyc.system.mapper;

import java.util.List;
import com.zyc.system.domain.ElasticIpServices;

/**
 * 弹性IP服务Mapper接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface ElasticIpServicesMapper 
{
    /**
     * 查询弹性IP服务
     * 
     * @param id 弹性IP服务主键
     * @return 弹性IP服务
     */
    public ElasticIpServices selectElasticIpServicesById(Integer id);

    /**
     * 查询弹性IP服务列表
     * 
     * @param elasticIpServices 弹性IP服务
     * @return 弹性IP服务集合
     */
    public List<ElasticIpServices> selectElasticIpServicesList(ElasticIpServices elasticIpServices);

    /**
     * 新增弹性IP服务
     * 
     * @param elasticIpServices 弹性IP服务
     * @return 结果
     */
    public int insertElasticIpServices(ElasticIpServices elasticIpServices);

    /**
     * 修改弹性IP服务
     * 
     * @param elasticIpServices 弹性IP服务
     * @return 结果
     */
    public int updateElasticIpServices(ElasticIpServices elasticIpServices);

    /**
     * 删除弹性IP服务
     * 
     * @param id 弹性IP服务主键
     * @return 结果
     */
    public int deleteElasticIpServicesById(Integer id);

    /**
     * 批量删除弹性IP服务
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteElasticIpServicesByIds(Integer[] ids);
}
